
    KIconLoader *loader = a.getIconLoader();
    QPixmap pixmap;


    KToolBar* toolbar = new KToolBar(&w);    

    pixmap = loader->loadIcon("filenew2.xpm");
    toolbar->insertButton(pixmap, 0,
			  SIGNAL(clicked()), &o,
			  SLOT(help()), TRUE, i18n("New Document"));
    
    
    pixmap = loader->loadIcon("fileopen.xpm");
    toolbar->insertButton(pixmap, 0,
			  SIGNAL(clicked()), &o,
			  SLOT(help()), TRUE, i18n("Open Document"));

    toolbar->setMaxWidth(100);
    w.addToolBar(toolbar);


    toolbar = new KToolBar(&w);    

    pixmap = loader->loadIcon("filenew2.xpm");
    toolbar->insertButton(pixmap, 0,
			  SIGNAL(clicked()), &o,
			  SLOT(help()), TRUE, i18n("gash"));
    
    
    pixmap = loader->loadIcon("fileopen.xpm");
    toolbar->insertButton(pixmap, 0,
			  SIGNAL(clicked()), &o,
			  SLOT(help()), TRUE, i18n("Goosh"));

    toolbar->setMaxWidth(150);
    w.addToolBar(toolbar);
    
